@@ -6,9 +6,9 @@ from typing import Optional
 from paxter.pyauthor.funcs.controls import for_statement, if_statement
 from paxter.pyauthor.funcs.document import (
     Blockquote, Bold, BulletedList, Code,
-    Heading1, Heading2, Heading3, Heading4, Heading5, Heading6,
-    HorizontalRule, Image, Italic, LineBreak, Link, NumberedList,
-    Paragraph, Underline,
+    HairSpace, Heading1, Heading2, Heading3, Heading4, Heading5, Heading6,
+    HorizontalRule, Image, Italic, LineBreak, Link, NonBreakingSpace, NumberedList,
+    Paragraph, RawElement, ThinSpace, Underline,
 )
 from paxter.pyauthor.funcs.standards import (
     flatten, python_unsafe_exec, starter_unsafe_eval, verb,
@@ -20,7 +20,7 @@ def create_unsafe_bare_env(data: Optional[dict] = None):
     Creates an string environment data for Paxter source code evaluation
     in Python authoring mode.
     """
-    data = data if data is not None else {}
+    data = data or {}
     return {
         '_starter_eval_': starter_unsafe_eval,
         'for': for_statement,
@@ -37,10 +37,22 @@ def create_unsafe_document_env(data: Optional[dict] = None):
     Creates an string environment data for Paxter source code evaluation
     in Python authoring mode, specializes in constructing documents.
     """
-    data = data if data is not None else {}
+    data = data or {}
+    symbols = data.pop('_symbols_', {})
+    symbols = {
+        '.': HairSpace,
+        ',': ThinSpace,
+        '*': NonBreakingSpace,
+        **symbols,
+    }
     return create_unsafe_bare_env({
+        '_symbols_': symbols,
+        'raw': RawElement,
         'break': LineBreak,
         'hrule': HorizontalRule,
+        'nbsp': NonBreakingSpace,
+        'hairsp': HairSpace,
+        'thinsp': ThinSpace,
         'paragraph': Paragraph,
         'h1': Heading1,
         'h2': Heading2,
@@ -48,11 +60,11 @@ def create_unsafe_document_env(data: Optional[dict] = None):
         'h4': Heading4,
         'h5': Heading5,
         'h6': Heading6,
-        'blockquote': Blockquote,
         'bold': Bold,
         'italic': Italic,
         'underline': Underline,
         'code': Code,
+        'blockquote': Blockquote,
         'link': Link,
         'image': Image,
         'numbered_list': NumberedList,
